@@ -93,28 +93,30 @@ GType 		 gedit_panel_get_type 			(void) G_GNUC_CONST;
 
 GtkWidget 	*gedit_panel_new 			(GtkOrientation	 orientation);
 
-void		 gedit_panel_add_item			(GeditPanel     *panel,
-						      	 GtkWidget      *item,
-						      	 const gchar    *name,
+gboolean	 gedit_panel_add_item			(GeditPanel     *panel,
+							 GtkWidget      *item,
+							 const gchar    *id,
+							 const gchar    *display_name,
 							 GtkWidget      *image);
 
-void		 gedit_panel_add_item_with_stock_icon	(GeditPanel     *panel,
+gboolean	 gedit_panel_add_item_with_stock_icon	(GeditPanel     *panel,
 							 GtkWidget      *item,
-						      	 const gchar    *name,
+							 const gchar    *id,
+						      	 const gchar    *display_name,
 						      	 const gchar    *stock_id);
 
-gboolean	 gedit_panel_remove_item	(GeditPanel     *panel,
-					  	 GtkWidget      *item);
+gboolean	 gedit_panel_remove_item		(GeditPanel     *panel,
+					  		 GtkWidget      *item);
 
-gboolean	 gedit_panel_activate_item 	(GeditPanel     *panel,
-					    	 GtkWidget      *item);
+gboolean	 gedit_panel_activate_item 		(GeditPanel     *panel,
+					    		 GtkWidget      *item);
 
-gboolean	 gedit_panel_item_is_active 	(GeditPanel     *panel,
-					    	 GtkWidget      *item);
+gboolean	 gedit_panel_item_is_active 		(GeditPanel     *panel,
+					    		 GtkWidget      *item);
 
-GtkOrientation	 gedit_panel_get_orientation	(GeditPanel	*panel);
+GtkOrientation	 gedit_panel_get_orientation		(GeditPanel	*panel);
 
-gint		 gedit_panel_get_n_items	(GeditPanel	*panel);
+gint		 gedit_panel_get_n_items		(GeditPanel	*panel);
 
 
 /*
@@ -128,3 +130,5 @@ void		 _gedit_panel_set_active_item_by_id	(GeditPanel	*panel,
 G_END_DECLS
 
 #endif  /* __GEDIT_PANEL_H__  */
+
+/* ex:ts=8:noet: */
